@@ -455,6 +455,12 @@ for ( ; ; )
  if (nutnum == ALA ) food_work.nutrient[F18D3] = tempfloat;
  if (nutnum == EPA ) food_work.nutrient[F20D5] = tempfloat;
  if (nutnum == DHA ) food_work.nutrient[F22D6] = tempfloat;
+ if (nutnum == TOCPHA) food_work.nutrient[VITE] = tempfloat * 3/2;
+ if (nutnum == F18D2 ) food_work.nutrient[LA] = tempfloat;
+ if (nutnum == F20D4 ) food_work.nutrient[AA] = tempfloat;
+ if (nutnum == F18D3 ) food_work.nutrient[ALA] = tempfloat;
+ if (nutnum == F20D5 ) food_work.nutrient[EPA] = tempfloat;
+ if (nutnum == F22D6 ) food_work.nutrient[DHA] = tempfloat;
  }
 }
 
