@@ -695,6 +695,8 @@ fprintf(fp,"%d^%f^\n",PROTCALPERGM,options.protcalpergm);
 fprintf(fp,"%d^%f^\n",CARBCALPERGM,options.carbcalpergm);
 fprintf(fp,"%d^%f^\n",FATCALPERGM,options.fatcalpergm);
 fprintf(fp,"%d^%f^\n",FATTYACIDFACTOR,options.fattyacidfactor);
+fprintf(fp,"%d^%f^\n",N6HUFA,options.n6hufa);
+fprintf(fp,"%d^%d^\n",N6HUFASPEC,options.n6hufaspec);
 for (i = 1; i <= DV_COUNT; i++)
  {
  switch (DVMap[i])
@@ -813,6 +815,10 @@ while (fgets(buffer,100,fp) != NULL)
                         break;
   case FATTYACIDFACTOR : options.fattyacidfactor = atof(valbuf1);
                         break;
+  case N6HUFA          : options.n6hufa = atof(valbuf1);
+                        break;
+  case N6HUFASPEC      : options.n6hufaspec = atoi(valbuf1);
+                        break;
   case OPT_CHO_NONFIB : options.abnuts[CHO_NONFIB] = atof(valbuf1);
                         options.locknuts[CHO_NONFIB] = atoi(valbuf2);
                         break;
