@@ -585,7 +585,7 @@ void food_display(FILE *fp)
 {
 int i;
 float pctfat = 0, pctcarb = 0, pctprot = 0;
-float p3, p6, h3, h6, o, calories;
+float p3, p6, h3, h6, o;
 char carbprotfat[9];
 if (food_work.nutrient[ENERC_KCAL] > 0.05)
  {
@@ -645,13 +645,12 @@ switch (options.screen)
  if (options.n6hufaspec)
   {
   food_display_line(fp,ScreenMap[options.screen][13+16],0,0,0,0);
-  calories = food_work.nutrient[ENERC_KCAL];
-  p3 = 902 * food_work.nutrient[ALA] / calories;
-  p6 = 902 * food_work.nutrient[LA] / calories;
-  h3 = 902 * (food_work.nutrient[EPA] + food_work.nutrient[DHA]) / calories;
-  h6 = 902 * food_work.nutrient[AA] / calories;
-  o  = 902 * (food_work.nutrient[FASAT] + food_work.nutrient[FAMS]) / calories;
-  fprintf(fp,"Omega-6 HUFA     %5.1f%%\n",n6hufa(p3,p6,h3,h6,o,calories));
+  p3 = 902 * food_work.nutrient[SHORT3] / food_work.nutrient[ENERC_KCAL];
+  p6 = 902 * food_work.nutrient[SHORT6] / food_work.nutrient[ENERC_KCAL];
+  h3 = 902 * food_work.nutrient[LONG3] / food_work.nutrient[ENERC_KCAL];
+  h6 = 902 * food_work.nutrient[LONG6] / food_work.nutrient[ENERC_KCAL];
+  o  = 902 * (food_work.nutrient[FASAT] + food_work.nutrient[FAMS]) / food_work.nutrient[ENERC_KCAL];
+  fprintf(fp,"Omega-6 HUFA     %5.1f%%\n",n6hufa(p3,p6,h3,h6,o));
   }
  break;
  case 2 :
@@ -767,13 +766,12 @@ switch (options.screen)
  if (options.n6hufaspec)
   {
   food_display_line(fp,ScreenMap[options.screen][13+16],1,0,0,0);
-  calories = food_work.nutrient[ENERC_KCAL];
-  p3 = 902 * food_work.nutrient[ALA] / calories;
-  p6 = 902 * food_work.nutrient[LA] / calories;
-  h3 = 902 * (food_work.nutrient[EPA] + food_work.nutrient[DHA]) / calories;
-  h6 = 902 * food_work.nutrient[AA] / calories;
-  o  = 902 * (food_work.nutrient[FASAT] + food_work.nutrient[FAMS]) / calories;
-  fprintf(fp,"Omega-6 HUFA     %5.0f%%\n",n6hufa(p3,p6,h3,h6,o,calories));
+  p3 = 902 * food_work.nutrient[SHORT3] / food_work.nutrient[ENERC_KCAL];
+  p6 = 902 * food_work.nutrient[SHORT6] / food_work.nutrient[ENERC_KCAL];
+  h3 = 902 * food_work.nutrient[LONG3] / food_work.nutrient[ENERC_KCAL];
+  h6 = 902 * food_work.nutrient[LONG6] / food_work.nutrient[ENERC_KCAL];
+  o  = 902 * (food_work.nutrient[FASAT] + food_work.nutrient[FAMS]) / food_work.nutrient[ENERC_KCAL];
+  fprintf(fp,"Omega-6 HUFA     %5.0f%%\n",n6hufa(p3,p6,h3,h6,o));
   }
  break;
  }
@@ -886,26 +884,34 @@ void compute_derived_fields(struct food *food_ptr)
 {
 float ratio;
 food_ptr->nutrient[VITE] = 1.5 * food_ptr->nutrient[TOCPHA];
-food_ptr->nutrient[LA] = food_ptr->nutrient[F18D2CN6] > 0 ? food_ptr->nutrient[F18D2CN6] : food_ptr->nutrient[F18D2] - food_ptr->nutrient[F18D2T] - food_ptr->nutrient[F18D2I] - food_ptr->nutrient[F18D2CLA];
+food_ptr->nutrient[LA] = food_ptr->nutrient[F18D2CN6] > 0 ? food_ptr->nutrient[F18D2CN6] : food_ptr->nutrient[F18D2] - food_ptr->nutrient[F18D2T] - food_ptr->nutrient[F18D2TT] - food_ptr->nutrient[F18D2I] - food_ptr->nutrient[F18D2CLA];
 if (food_ptr->nutrient[LA] == 0 && test_for_negative_zero(&food_ptr->nutrient[F18D2])) food_ptr->nutrient[LA] = NoData;
 if (food_ptr->nutrient[LA] < 0) food_ptr->nutrient[LA] = 0;
-food_ptr->nutrient[OMEGA6] = food_ptr->nutrient[LA];
+food_ptr->nutrient[SHORT6] = food_ptr->nutrient[LA];
+food_ptr->nutrient[SHORT6] += food_ptr->nutrient[F18D3CN6];
 food_ptr->nutrient[ALA] = food_ptr->nutrient[F18D3CN3] > 0 ? food_ptr->nutrient[F18D3CN3] : food_ptr->nutrient[F18D3] - food_ptr->nutrient[F18D3CN6] - food_ptr->nutrient[F18D3I];
 if (food_ptr->nutrient[ALA] == 0 && test_for_negative_zero(&food_ptr->nutrient[F18D3])) food_ptr->nutrient[ALA] = NoData;
 if (food_ptr->nutrient[ALA] < 0) food_ptr->nutrient[ALA] = 0;
-food_ptr->nutrient[OMEGA3] = food_ptr->nutrient[ALA];
-food_ptr->nutrient[OMEGA3] += food_ptr->nutrient[F18D4];
-food_ptr->nutrient[OMEGA6] += food_ptr->nutrient[F20D2CN6];
-food_ptr->nutrient[OMEGA6] += food_ptr->nutrient[F20D3];
-food_ptr->nutrient[OMEGA6] += food_ptr->nutrient[F20D4];
+food_ptr->nutrient[SHORT3] = food_ptr->nutrient[ALA];
+food_ptr->nutrient[SHORT3] += food_ptr->nutrient[F18D4];
+food_ptr->nutrient[LONG6] = food_ptr->nutrient[F20D2CN6];
+food_ptr->nutrient[LONG6] += food_ptr->nutrient[F20D3];
 food_ptr->nutrient[AA] = food_ptr->nutrient[F20D4];
-food_ptr->nutrient[OMEGA3] += food_ptr->nutrient[F20D5];
+if (food_ptr->nutrient[F20D4N6] > 0) food_ptr->nutrient[AA] = food_ptr->nutrient[F20D4N6];
+food_ptr->nutrient[LONG6] += food_ptr->nutrient[AA];
 food_ptr->nutrient[EPA] = food_ptr->nutrient[F20D5];
-food_ptr->nutrient[OMEGA3] += food_ptr->nutrient[F22D5];
-food_ptr->nutrient[OMEGA3] += food_ptr->nutrient[F22D6];
+food_ptr->nutrient[LONG3] = food_ptr->nutrient[F20D5];
+food_ptr->nutrient[LONG3] += food_ptr->nutrient[F22D5];
 food_ptr->nutrient[DHA] = food_ptr->nutrient[F22D6];
-if (food_ptr->nutrient[OMEGA3] == 0 && test_for_negative_zero(&food_ptr->nutrient[ALA]) && test_for_negative_zero(&food_ptr->nutrient[EPA]) && test_for_negative_zero(&food_ptr->nutrient[DHA])) food_ptr->nutrient[OMEGA3] = NoData;
-if (food_ptr->nutrient[OMEGA6] == 0 && test_for_negative_zero(&food_ptr->nutrient[LA]) && test_for_negative_zero(&food_ptr->nutrient[AA])) food_ptr->nutrient[OMEGA6] = NoData;
+food_ptr->nutrient[LONG3] += food_ptr->nutrient[F22D6];
+if (food_ptr->nutrient[SHORT3] == 0 && test_for_negative_zero(&food_ptr->nutrient[ALA]) && test_for_negative_zero(&food_ptr->nutrient[F18D4])) food_ptr->nutrient[SHORT3] = NoData;
+if (food_ptr->nutrient[LONG3] == 0 && test_for_negative_zero(&food_ptr->nutrient[EPA]) && test_for_negative_zero(&food_ptr->nutrient[F22D5]) && test_for_negative_zero(&food_ptr->nutrient[DHA])) food_ptr->nutrient[LONG3] = NoData;
+if (food_ptr->nutrient[SHORT6] == 0 && test_for_negative_zero(&food_ptr->nutrient[LA]) && test_for_negative_zero(&food_ptr->nutrient[F18D3CN6])) food_ptr->nutrient[SHORT6] = NoData;
+if (food_ptr->nutrient[LONG6] == 0 && test_for_negative_zero(&food_ptr->nutrient[EPA]) && test_for_negative_zero(&food_ptr->nutrient[F22D5]) && test_for_negative_zero(&food_ptr->nutrient[DHA])) food_ptr->nutrient[LONG6] = NoData;
+food_ptr->nutrient[OMEGA6] = food_ptr->nutrient[SHORT6] + food_ptr->nutrient[LONG6];
+if (food_ptr->nutrient[OMEGA6] == 0 && test_for_negative_zero(&food_ptr->nutrient[SHORT6]) && test_for_negative_zero(&food_ptr->nutrient[LONG6])) food_ptr->nutrient[OMEGA6] = NoData;
+food_ptr->nutrient[OMEGA3] = food_ptr->nutrient[SHORT3] + food_ptr->nutrient[LONG3];
+if (food_ptr->nutrient[OMEGA3] == 0 && test_for_negative_zero(&food_ptr->nutrient[SHORT3]) && test_for_negative_zero(&food_ptr->nutrient[LONG3])) food_ptr->nutrient[OMEGA3] = NoData;
 
 if ( food_ptr->prot_cal_factor == 0 && food_ptr->fat_cal_factor == 0 && food_ptr->cho_cal_factor == 0 && food_ptr->nutrient[ENERC_KCAL] > 0)
  {
@@ -964,12 +970,12 @@ buffer[49] = '\0';
 return buffer;
 }
 
-float n6hufa(float p3, float p6, float h3, float h6, float o, float calories)
+float n6hufa(float p3, float p6, float h3, float h6, float o)
 {
 float pc6 = .0441, pc3 = .0555, co = 5, ks = .175, hi3 = .005, hc6 = .7, hc3 = 3;
 float answer;
 /*
-printf("%f %f %f %f %f %f\n",p3,p6,h3,h6,o,calories);
+printf("%f %f %f %f %f\n",p3,p6,h3,h6,o);
 exit(0);
 */  
 answer = 100 / (1 + pc6/p6 * (1 + p3/pc3 + h3/hi3 + o/co + p6/ks)) + 100 / (1 + hc6/h6 * (1 + h3/hc3));
