@@ -86,6 +86,6 @@ float dv_fat(void);
 float dv_cho(void);
 float dv_pro(void);
 char *format_serving(char *, float *, struct food *);
-float n6hufa(float, float, float, float, float, float);
+float n6hufa(float, float, float, float, float);
 
 #endif
