@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 2005 Jim Jozwiak.
+    Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -171,10 +171,11 @@ while (meal_ptr->next != meal_after) meal_ptr = meal_ptr->next;
 return meal_ptr;
 }
 
-void delete_meal(char *meal_date, int meal, int num)
+void modify_meal(char *meal_date, int meal, int num, char *qty)
 {
 struct meal *m, *meal_ptr = &meal_root;
 int count = 0;
+float newqty;
 while (meal_ptr->next != NULL)
  {
  if (strcmp(meal_date,meal_ptr->next->meal_date) == 0 && meal == meal_ptr->next->meal) 
@@ -182,9 +183,14 @@ while (meal_ptr->next != NULL)
   count++;
   if (count == num)
    {
-   m = meal_ptr->next;
-   meal_ptr->next = meal_ptr->next->next;
-   free(m);
+   newqty = evaluate_qty(food_number(meal_ptr->next->food_no),qty);
+   if (newqty == 0)
+    {
+    m = meal_ptr->next;
+    meal_ptr->next = meal_ptr->next->next;
+    free(m);
+    }
+   else meal_ptr->next->grams = newqty;
    return;
    }
   }
@@ -222,10 +228,11 @@ while (meal_ptr->next != NULL)
  }
 }
 
-void delete_theusual(char *meal_date, int num)
+void modify_theusual(char *meal_date, int num, char *qty)
 {
 struct meal *m, *theusual_ptr = &theusual_root;
 int count = 0;
+float newqty;
 while (theusual_ptr->next != NULL)
  {
  if (strcmp(meal_date,theusual_ptr->next->meal_date) == 0) 
@@ -233,9 +240,14 @@ while (theusual_ptr->next != NULL)
   count++;
   if (count == num)
    {
-   m = theusual_ptr->next;
-   theusual_ptr->next = theusual_ptr->next->next;
-   free(m);
+   newqty = evaluate_qty(food_number(theusual_ptr->next->food_no),qty);
+   if (newqty == 0)
+    {
+    m = theusual_ptr->next;
+    theusual_ptr->next = theusual_ptr->next->next;
+    free(m);
+    }
+   else theusual_ptr->next->grams = newqty;
    return;
    }
   }
@@ -373,6 +385,7 @@ while (meal_ptr->next != NULL)
  while (meal_ptr->next->food_no == -1)
   {
   delete_meal_with_ptr(meal_ptr->next);
+  if (meal_ptr->next == NULL) break;
   if (meal_ptr->next->ndb_no == 0 && version(0) < 9) meal_ptr->next->ndb_no = 42231;
   meal_ptr->next->food_no = find_ndbno(meal_ptr->next->ndb_no);
   }
@@ -390,6 +403,7 @@ while (meal_ptr->next != NULL)
  while (meal_ptr->next->food_no == -1)
   {
   delete_theusual_with_ptr(meal_ptr->next);
+  if (meal_ptr->next == NULL) return;
   if (meal_ptr->next->ndb_no == 0 && version(0) < 9) meal_ptr->next->ndb_no = 42231;
   meal_ptr->next->food_no = find_ndbno(meal_ptr->next->ndb_no);
   }
