@@ -205,6 +205,7 @@ for ( ; ; )
  {
  sprintf(calflag,"%s %5.1f %s",(options.locknuts[ENERC_KCAL] ? "(LOCKED:" : options.autocal ? "(AUTO-SET:"  : "(SET:"),options.abnuts[ENERC_KCAL],"kc)");
  sprintf(pufaflag,"%s %4.1f %s",options.locknuts[FAPU] ? "(LOCKED:" : "(SET:",options.abnuts[FAPU],"g)");
+ if (options.locknuts[FAPU] == 0 && options.n6hufaspec) sprintf(pufaflag,"%s","(SPECIAL)");
  sprintf(pcproteinflag,"%s %5.1f%s",options.locknuts[PROCNT] && options.pcprotein > 0 ? "(LOCKED:" : "(SET:",options.pcprotein,"%)");
  sprintf(pccarbflag,"%s %5.1f%s",options.locknuts[CHOCDF] && options.pccarb > 0 ? "(LOCKED:" : "(SET:",options.pccarb,"%)");
  sprintf(pcsatfatflag,"%s %5.1f%s",options.locknuts[FASAT] ? "(LOCKED:" : "(SET:",options.pcsatfat,"%)");
@@ -214,7 +215,7 @@ for ( ; ; )
  sprintf(fatprotflag,"%s %5.2f%s",options.fatprotratio > 0 && options.locknuts[PROCNT] ? "(LOCKED:" : "(SET:",options.fatprotratio,")");
  header("NUT:  Personal Options");
  printf("                1  --  Change Calorie Level %s\n\n",options.abnuts[ENERC_KCAL] != 2000 || options.locknuts[ENERC_KCAL] || options.autocal ? calflag : "(default)");
- printf("                2  --  Essential Fats Absolute Amount %s\n\n",options.abnuts[FAPU] ? pufaflag : "(default)");
+ printf("                2  --  Essential Fats Absolute Amount %s\n\n",(options.abnuts[FAPU] || options.n6hufaspec) ? pufaflag : "(default)");
  printf("                3  --  Saturated Fat Percentage %s\n\n",options.pcsatfat ? pcsatfatflag : "(default)");
  printf("                4  --  Fiber Absolute Amount %s\n\n",options.abnuts[FIBTG] ? abfiberflag : "(default)");
  printf("                5  --  Carbohydrate Percentage %s\n\n",options.pccarb ? pccarbflag : "(default)");
