@@ -165,9 +165,13 @@
 #define EPA 143
 #define DHA 144
 #define OMEGA6 145
-#define OMEGA3 146
-#define VITE 147
+#define SHORT6 146
+#define LONG6 147
+#define OMEGA3 148
+#define SHORT3 149
+#define LONG3 150
+#define VITE 151
 
-#define NUTRIENT_COUNT 148
-#define DERIVED 12
+#define NUTRIENT_COUNT 152
+#define DERIVED 16
 #define NUTRNO_ARRAYSIZE 859
