@@ -380,7 +380,7 @@ fgets(buff,128,stdin);
 
 void auto_cal(float *bufptr, int analflag)
 {
-float buf = *bufptr, temp = 0, temp1 = 0;
+float buf = *bufptr, temp = 0;
 int i;
 if (options.autocal) buf = average_cals(analflag);
 if (analflag)
@@ -465,16 +465,18 @@ if (options.abnuts[FAPU] > 0)
  if (options.abnuts[EPA] > 0) DV[EPA] = options.abnuts[EPA];
  if (options.abnuts[DHA] > 0) DV[DHA] = options.abnuts[DHA];
  }
-if (options.abnuts[FAPU] == 0 && options.abnuts[AA] > 0 && options.abnuts[EPA] > 0 && options.abnuts[DHA] > 0)
+if (options.abnuts[FAPU] == 0)
  {
- temp = options.abnuts[AA] - DV[AA]; DV[AA] += temp; DV[OMEGA6] += temp; DV[FAPU] += temp; DV[FAMS] -= temp;
- temp = options.abnuts[EPA] - DV[EPA]; DV[EPA] += temp; DV[OMEGA3] += temp; DV[FAPU] += temp; DV[FAMS] -= temp;
- temp = options.abnuts[DHA] - DV[DHA]; DV[DHA] += temp; DV[OMEGA3] += temp; DV[FAPU] += temp; DV[FAMS] -= temp;
- }
-if (options.abnuts[FAPU] == 0 && options.abnuts[LA] > 0 && options.abnuts[ALA] > 0)
- {
- temp1 = options.abnuts[LA] - DV[LA]; DV[LA] += temp1; DV[OMEGA6] += temp1; DV[FAPU] += temp1; DV[FAMS] -= temp1;
- temp1 = options.abnuts[ALA] - DV[ALA]; DV[ALA] += temp1; DV[OMEGA3] += temp1; DV[FAPU] += temp1; DV[FAMS] -= temp1;
+ DV[OMEGA6] = options.abnuts[OMEGA6];
+ DV[LA] = options.abnuts[LA];
+ DV[AA] = options.abnuts[AA];
+ DV[OMEGA3] = options.abnuts[OMEGA3];
+ DV[ALA] = options.abnuts[ALA];
+ DV[EPA] = options.abnuts[EPA];
+ DV[DHA] = options.abnuts[DHA];
+ temp = DV[OMEGA6] + DV[OMEGA3] - DV[FAPU];
+ DV[FAPU] += temp;
+ DV[FAMS] -= temp;
  }
 if (options.pcsatfat > 0)
  {
@@ -510,10 +512,10 @@ if (options.abnuts[ZN] > 0) DV[ZN] = options.abnuts[ZN];
 if (! options.abnuts[CHO_NONFIB]) DV[CHO_NONFIB] = DV[CHOCDF] - DV[FIBTG] < 0 ? 0 : DV[CHOCDF] - DV[FIBTG];
 else DV[CHO_NONFIB] = options.abnuts[CHO_NONFIB];
 temp = 1 - (DV[PROCNT] * options.protcalpergm + DV[CHOCDF] * options.carbcalpergm) / DV[ENERC_KCAL];
-if (temp > .32 && options.pcsatfat <= 0 && options.abnuts[FASAT] <= 0 && options.abnuts[FAMS] <= 0) 
+if (temp > .3 && options.pcsatfat <= 0 && options.abnuts[FASAT] <= 0 && options.abnuts[FAMS] <= 0) 
  {
  temp = DV[FAMS] + DV[FASAT];
- DV[FASAT] = temp / 3;
+ if (temp * .35 > DV[FASAT]) DV[FASAT] = temp * .35;
  DV[FAMS] = temp - DV[FASAT];
  }
 if ( options.pcsatfat > 0 || options.pcprotein > 0 || options.pccarb > 0 || options.fatprotratio || options.abnuts[PROCNT] > 0 || options.abnuts[CHOCDF] > 0 || options.abnuts[FIBTG] > 0 || options.abnuts[VITE]) options.custom = 1;
@@ -684,8 +686,8 @@ while (meal_ptr->next != NULL)
 void efa_dynamics()
 {
 int i;
-float temp, hufapct,calories, p3, h3, h6, p6, o;
-float target = 76;
+float temp, hufapct, p3, h3, h6, p6, o;
+float target = 55;
 
 if (options.n6hufa != 0)
  {
@@ -696,43 +698,68 @@ if (options.n6hufa != 0)
 options.abnuts[AA] = food_work.nutrient[AA];
 options.abnuts[LA] = food_work.nutrient[LA];
 options.abnuts[ALA] = food_work.nutrient[ALA];
+p3 = 902 * food_work.nutrient[SHORT3] / food_work.nutrient[ENERC_KCAL];
+p6 = 902 * food_work.nutrient[SHORT6] / food_work.nutrient[ENERC_KCAL];
+h6 = 902 * food_work.nutrient[LONG6] / food_work.nutrient[ENERC_KCAL];
+o  = 902 * (food_work.nutrient[FASAT] + food_work.nutrient[FAMS]) / food_work.nutrient[ENERC_KCAL];
 
 if (food_work.nutrient[EPA] > .02 || food_work.nutrient[DHA] > .02 || food_work.nutrient[AA] > .02) for (i = 1; i < 200000; i++)
  {
  temp = i * .001;
-
- calories = food_work.nutrient[ENERC_KCAL];
- p3 = 902 * options.abnuts[ALA] / calories;
- p6 = 902 * options.abnuts[LA] / calories;
- h3 = 902 * temp / calories;
- h6 = 902 * options.abnuts[AA] / calories;
- o  = 902 * (food_work.nutrient[FASAT] + food_work.nutrient[FAMS]) / calories;
- hufapct = n6hufa(p3,p6,h3,h6,o,calories);
+ h3 = 902 * temp / food_work.nutrient[ENERC_KCAL];
+ hufapct = n6hufa(p3,p6,h3,h6,o);
 
  if (options.n6hufa <= 0 && hufapct > target) continue;
  if (options.n6hufa > 0 && hufapct > options.n6hufa) continue;
 
- temp -= food_work.nutrient[F22D5] + food_work.nutrient[F18D4];
+ options.abnuts[OMEGA6] = food_work.nutrient[SHORT6] + food_work.nutrient[LONG6];
+ options.abnuts[OMEGA3] = food_work.nutrient[SHORT3] + temp;
+ temp -= food_work.nutrient[LONG3] - food_work.nutrient[EPA] - food_work.nutrient[DHA];
  if (food_work.nutrient[EPA] > 0 || food_work.nutrient[DHA] > 0) temp = temp / (food_work.nutrient[EPA] + food_work.nutrient[DHA]);
  options.abnuts[EPA] = food_work.nutrient[EPA] * temp;
  options.abnuts[DHA] = food_work.nutrient[DHA] * temp;
+ if (options.abnuts[DHA] > DV[ENERC_KCAL] / 2000)
+  {
+  temp = options.abnuts[DHA] - DV[ENERC_KCAL] / 2000;
+  options.abnuts[DHA] = DV[ENERC_KCAL] / 2000;
+  options.abnuts[EPA] += temp;
+  }
+ if (options.abnuts[OMEGA6] == 0) options.abnuts[OMEGA6] = .01;
+ if (options.abnuts[LA] == 0) options.abnuts[LA] = .01;
+ if (options.abnuts[AA] == 0) options.abnuts[AA] = .01;
+ if (options.abnuts[OMEGA3] == 0) options.abnuts[OMEGA3] = .01;
+ if (options.abnuts[ALA] == 0) options.abnuts[ALA] = .01;
+ if (options.abnuts[EPA] == 0) options.abnuts[EPA] = .01;
+ if (options.abnuts[DHA] == 0) options.abnuts[DHA] = .01;
  return;
  }
-else for (i = 1; i < 200000; i++)
+else
  {
- temp = i * .001;
+ h3 = 902 * food_work.nutrient[LONG3] / food_work.nutrient[ENERC_KCAL];
+ for (i = 1; i < 200000; i++)
+  {
+  temp = i * .001;
 
- calories = food_work.nutrient[ENERC_KCAL];
- p3 = 902 * temp / calories;
- p6 = 902 * options.abnuts[LA] / calories;
- h3 = 0;
- h6 = 0;
- o  = 902 * (food_work.nutrient[FASAT] + food_work.nutrient[FAMS]) / calories;
- hufapct = n6hufa(p3,p6,h3,h6,o,calories);
+  p3 = 902 * temp / food_work.nutrient[ENERC_KCAL];
+  o  = 902 * (food_work.nutrient[FASAT] + food_work.nutrient[FAMS]) / food_work.nutrient[ENERC_KCAL];
+  hufapct = n6hufa(p3,p6,h3,h6,o);
 
- if (options.n6hufa <= 0 && hufapct > target) continue;
- if (options.n6hufa > 0 && hufapct > options.n6hufa) continue;
- options.abnuts[ALA] = temp;
- return;
+  if (options.n6hufa <= 0 && hufapct > target) continue;
+  if (options.n6hufa > 0 && hufapct > options.n6hufa) continue;
+  options.abnuts[OMEGA6] = food_work.nutrient[SHORT6] + food_work.nutrient[LONG6];
+  options.abnuts[OMEGA3] = food_work.nutrient[LONG3] + temp;
+  temp -= food_work.nutrient[SHORT3] - food_work.nutrient[ALA];
+  options.abnuts[ALA] = temp;
+  options.abnuts[EPA] = .01;
+  options.abnuts[DHA] = .01;
+  if (options.abnuts[OMEGA6] == 0) options.abnuts[OMEGA6] = .01;
+  if (options.abnuts[LA] == 0) options.abnuts[LA] = .01;
+  if (options.abnuts[AA] == 0) options.abnuts[AA] = .01;
+  if (options.abnuts[OMEGA3] == 0) options.abnuts[OMEGA3] = .01;
+  if (options.abnuts[ALA] == 0) options.abnuts[ALA] = .01;
+  if (options.abnuts[EPA] == 0) options.abnuts[EPA] = .01;
+  if (options.abnuts[DHA] == 0) options.abnuts[DHA] = .01;
+  return;
+  }
  }
 }
