@@ -39,6 +39,8 @@ struct opt
  float protcalpergm;
  float fatcalpergm;
  float fattyacidfactor;
+ float n6hufa;
+ int n6hufaspec;
  int next_recipe;
  int locknuts[NUTRIENT_COUNT];
  float abnuts[NUTRIENT_COUNT];
@@ -64,6 +66,8 @@ struct opt
 #define CARBCALPERGM  1013
 #define FATCALPERGM   1014
 #define FATTYACIDFACTOR 1015
+#define N6HUFA        1016
+#define N6HUFASPEC    1017
 
 #define OPT_CHO_NONFIB 2000
 #define OPT_LA         2001
@@ -96,5 +100,6 @@ void get_cals(float *);
 void new_nut_levels(void);
 void restore_defaults(int);
 void set_defanal(void);
+void efa_dynamics();
 
 #endif
